@@ -1,7 +1,7 @@
 from bokeh.server.server import Server
 from bokeh.layouts import column, row
 from bokeh.models import *
-from bokeh.plotting import Figure
+from bokeh.plotting import figure
 from openautomatumdronedata.dataset import droneDataset
 from bokeh.palettes import Dark2_5 as palette
 from bokeh.palettes import Category20_20 as palette_major
@@ -141,7 +141,7 @@ class automatumDataBokeh():
                     ttc = "%.3f" % obj.ttc_dict_vec[idx]["front_ego"]
 
 
-            live_plot_dict["info"].append("UUID: %s - v_x: %.3f - v_y: %.3f - TTC Front: %s - TTH Front: %s" % (obj.UUID, obj.vx_vec[idx], obj.vy_vec[idx], ttc, tth))
+            live_plot_dict["info"].append("Type: %s -  UUID: %s - v_x: %.3f - v_y: %.3f - TTC Front: %s - TTH Front: %s" % (obj.type, obj.UUID, obj.vx_vec[idx], obj.vy_vec[idx], ttc, tth))
 
             if(0 in self.extra_plot_option_checkbox.active and obj.object_relation_dict_list is not None):
                 relation_dict = obj.object_relation_dict_list[idx]
@@ -334,13 +334,13 @@ class automatumDataBokeh():
         """
             Creates the layout for the live plotting area. 
         """
-        # Add Figures
+        # Add figures
         self.livePlotTitle = Title()
         self.livePlotTitle.text = 'Live plot of dataset:'
         TOOLTIPS = [
             ("Info", "@info")
         ]           
-        self.live_plot = Figure(plot_width=1000, plot_height=1000, match_aspect=True, tooltips=TOOLTIPS)
+        self.live_plot = figure(width=1000, height=1000, match_aspect=True, tooltips=TOOLTIPS)
         self.live_plot.title = self.livePlotTitle
         self.live_plot_data = ColumnDataSource(data={
             "xdata": [],
@@ -387,13 +387,13 @@ class automatumDataBokeh():
         """
             Creates the layout for the trajectory plotting area. 
         """        
-        # Add Figures
+        # Add figures
         t = Title()
         t.text = 'Trajectories of dataset:'
         TOOLTIPS = [
             ("Info", "@info")
         ]           
-        self.traj_plot = Figure(plot_width=1000, plot_height=1000, match_aspect=True, tooltips=TOOLTIPS)
+        self.traj_plot = figure(width=1000, height=1000, match_aspect=True, tooltips=TOOLTIPS)
         self.traj_plot.title = t
         self.traj_plot_data = ColumnDataSource(data={
             "xdata": [],
