@@ -112,6 +112,7 @@ class dynamicObject():
 
         Per Object the following information are available as scalar:
 
+        :var type: Type of the object as string
         :var length:  Length of the object \[m\]
         :var width:  Width of the object \[m\]
         :var UUID:  Unique UUID of the object 
@@ -125,17 +126,22 @@ class dynamicObject():
         :var vy_vec:  Velocity in Y-direction of the local coordinate system 
         :var ax_vec:  Acceleration of the object in X-direction **in the vehicle coordinate system**
         :var ay_vec:  Acceleration of the object in Y-direction **in the vehicle coordinate system**
+        :var jerk_x_vec:  Jerk of the object in X-direction **in the vehicle coordinate system**. Only if available in your dataset, if not the value is None 
+        :var jerk_y_vec:  Jerk of the object in Y-direction **in the vehicle coordinate system**. Only if available in your dataset, if not the value is None
         :var time:  Vector of the timestamp in the dataset recording for the mention values. 
-        :var psi_vec:  Vector of orientation of objects 
+        :var psi_vec:  Vector of orientation of objects. 
+        :var curvature_vec:  Driving Curvature of the object. Only if available in your dataset, if not the value is None
         :var lane_id_vec:  Id of the lane of the object in the corresponding xodr 
         :var road_id_vec:  Id of the road of the object in the corresponding xodr 
-        :var object_relation_dict_list: Gives the UUID of all sourind objects as a dict in format ```{"front_ego": <uuid>,  "behind_ego": <uuid>,  "front_left": <uuid>,  "behind_left": <uuid>,  "front_right": <uuid>,  "behind_right": <uuid>}``` If an object relation does not exist, e.g. since there is no object, than the value will be ```None``. 
-        :var lane_change_flag_vec: Vector of bool values, whereby True means that a lane change occured
+        :var road_type_list: List of strings that describes the road type at every time step of the object. Only if available in your dataset, if not the value is None
+        :var object_relation_dict_list: Gives the UUID of all surrounding objects as a dict in format ```{"front_ego": <uuid>,  "behind_ego": <uuid>,  "front_left": <uuid>,  "behind_left": <uuid>,  "front_right": <uuid>,  "behind_right": <uuid>}``` If an object relation does not exist, e.g. since there is no object, than the value will be ```None``. 
+        :var lane_change_flag_vec: Vector of bool values, whereby True means that a lane change occurred. In newer Datasets a vector of Integers. Whereby, -1 means lane change to the left, +1 means lane change to the right and 0 means no lane change. 
         :var distance_left_lane_marking: Vector which gives the distance to the left lane marking
         :var distance_right_lane_marking: Vector which gives the distance to the right lane marking
-        :var tth_dict_vec: Gives the Time-To-Collsion to all sourind objects as a dict in format ```{"front_ego": <ttc>,  "behind_ego": <ttc>,  "front_left": <ttc>,  "behind_left": <ttc>,  "front_right": <ttc>,  "behind_right": <ttc>}``` If the value can not be calculated, e.g. the relevant object is to fast, than the value will be set to ```-1```. If no object exists, the value will be set to ```None``` 
-        :var ttc_dict_vec: Gives the Time-To-Headway to all sourind objects as a dict in format ```{"front_ego": <tth>,  "behind_ego": <tth>,  "front_left": <tth>,  "behind_left": <tth>,  "front_right": <tth>,  "behind_right": <tth>}``` If the value can not be calculated, e.g. the relevant object is to fast, than the value will be set to ```-1```. If no object exists, the value will be set to ```None``` 
-
+        :var tth_dict_vec: Gives the Time-To-Collision to all surrounding objects as a dict in format ```{"front_ego": <ttc>,  "behind_ego": <ttc>,  "front_left": <ttc>,  "behind_left": <ttc>,  "front_right": <ttc>,  "behind_right": <ttc>}``` If the value can not be calculated, e.g. the relevant object is to fast, than the value will be set to ```-1```. If no object exists, the value will be set to ```None``` 
+        :var ttc_dict_vec: Gives the Time-To-Headway to all surrounding objects as a dict in format ```{"front_ego": <tth>,  "behind_ego": <tth>,  "front_left": <tth>,  "behind_left": <tth>,  "front_right": <tth>,  "behind_right": <tth>}``` If the value can not be calculated, e.g. the relevant object is to fast, than the value will be set to ```-1```. If no object exists, the value will be set to ```None``` 
+        :var lat_dist_dict_vec: Gives the lateral distance the surrounding objects as a dict in format ```{"front_ego": <latDist>,  "behind_ego": <latDist>,  "front_left": <latDist>,  "behind_left": <latDist>,  "front_right": <latDist>,  "behind_right": <latDist>}```. If no object exists, the value will be set to ```None```.  Only if available in your dataset, if not the value is None
+        :var long_dist_dict_vec: Gives the long distance the surrounding objects as a dict in format ```{"front_ego": <longDist>,  "behind_ego": <longDist>,  "front_left": <longDist>,  "behind_left": <longDist>,  "front_right": <longDist>,  "behind_right": <longDist>}```. If no object exists, the value will be set to ```None```.  Only if available in your dataset, if not the value is None
     """
     def __init__(self, movement_dynamic, delta_t):
         self.x_vec = movement_dynamic["x_vec"]
@@ -191,7 +197,36 @@ class dynamicObject():
         else:
             self.ttc_dict_vec = None                         
             
+        if("lat_dist_dict_vec" in movement_dynamic):
+            self.lat_dist_dict_vec = movement_dynamic["lat_dist_dict_vec"]
+        else:
+            self.lat_dist_dict_vec = None    
 
+        if("long_dist_dict_vec" in movement_dynamic):
+            self.long_dist_dict_vec = movement_dynamic["long_dist_dict_vec"]
+        else:
+            self.long_dist_dict_vec = None     
+
+        if("jerk_x_vec" in movement_dynamic):
+            self.jerk_x_vec = movement_dynamic["jerk_x_vec"]
+        else:
+            self.jerk_x_vec = None    
+
+        if("jerk_y_vec" in movement_dynamic):
+            self.jerk_y_vec = movement_dynamic["jerk_y_vec"]
+        else:
+            self.jerk_y_vec = None 
+
+
+        if("curvature_vec" in movement_dynamic):
+            self.curvature_vec = movement_dynamic["curvature_vec"]
+        else:
+            self.curvature_vec = None    
+
+        if("road_type_list" in movement_dynamic):
+            self.road_type_list = movement_dynamic["road_type_list"]
+        else:
+            self.road_type_list = None                                                       
 
     def __eq__(self, other):
         """Overwrite compare operator
@@ -323,6 +358,7 @@ class carObject(dynamicObject):
     
     def __init__(self, movement_dynamic, delta_t):
         dynamicObject.__init__(self, movement_dynamic, delta_t)
+        self.type = "car"
         
 
 class truckObject(dynamicObject):
@@ -332,6 +368,7 @@ class truckObject(dynamicObject):
     """
     def __init__(self, movement_dynamic, delta_t):
         dynamicObject.__init__(self, movement_dynamic, delta_t)
+        self.type = "truck"
         
 
 class carWithTrailerObject(dynamicObject):
@@ -341,6 +378,7 @@ class carWithTrailerObject(dynamicObject):
     """
     def __init__(self, movement_dynamic, delta_t):
         dynamicObject.__init__(self, movement_dynamic, delta_t)
+        self.type = "carWithTrailer"
 
 class vanObject(dynamicObject):
     """
@@ -349,6 +387,7 @@ class vanObject(dynamicObject):
     """
     def __init__(self, movement_dynamic, delta_t):
         dynamicObject.__init__(self, movement_dynamic, delta_t)
+        self.type = "van"
         
 
 class motorcycleObject(dynamicObject):
@@ -358,6 +397,7 @@ class motorcycleObject(dynamicObject):
     """
     def __init__(self, movement_dynamic, delta_t):
         dynamicObject.__init__(self, movement_dynamic, delta_t)
+        self.type = "motorcycle"
 
 
 
